@@ -186,14 +186,7 @@ private:
     Q_DECLARE_PRIVATE(BreakpointModel)
 };
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
 Q_DECLARE_OPERATORS_FOR_FLAGS(BreakpointModel::ColumnFlags)
-#endif
-
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-Q_DECLARE_OPERATORS_FOR_FLAGS(KDevelop::BreakpointModel::ColumnFlags)
-#endif
-
 #endif
